@@ -16,14 +16,14 @@ from .const import (
     SwitchbotAuthenticationError,
     SwitchbotModel,
 )
-from .devices.device import SwitchbotEncryptedDevice
 from .devices.base_light import SwitchbotBaseLight
 from .devices.blind_tilt import SwitchbotBlindTilt
 from .devices.bot import Switchbot
 from .devices.bulb import SwitchbotBulb
 from .devices.ceiling_light import SwitchbotCeilingLight
 from .devices.curtain import SwitchbotCurtain
-from .devices.device import ColorMode, SwitchbotDevice
+from .devices.device import ColorMode, SwitchbotDevice, SwitchbotEncryptedDevice
+from .devices.evaporative_humidifier import SwitchbotEvaporativeHumidifier
 from .devices.humidifier import SwitchbotHumidifier
 from .devices.light_strip import SwitchbotLightStrip
 from .devices.lock import SwitchbotLock
@@ -33,30 +33,35 @@ from .discovery import GetSwitchbotDevices
 from .models import SwitchBotAdvertisement
 
 __all__ = [
-    "get_device",
-    "close_stale_connections",
-    "close_stale_connections_by_address",
-    "parse_advertisement_data",
+    "ColorMode",
     "GetSwitchbotDevices",
+    "LockStatus",
     "SwitchBotAdvertisement",
+    "Switchbot",
+    "Switchbot",
     "SwitchbotAccountConnectionError",
     "SwitchbotApiError",
     "SwitchbotAuthenticationError",
-    "SwitchbotEncryptedDevice",
-    "ColorMode",
-    "LockStatus",
     "SwitchbotBaseLight",
+    "SwitchbotBlindTilt",
     "SwitchbotBulb",
     "SwitchbotCeilingLight",
-    "SwitchbotDevice",
     "SwitchbotCurtain",
-    "SwitchbotLightStrip",
+    "SwitchbotDevice",
+    "SwitchbotEncryptedDevice",
+    "SwitchbotEvaporativeHumidifier",
     "SwitchbotHumidifier",
-    "Switchbot",
-    "SwitchbotPlugMini",
-    "SwitchbotSupportedType",
-    "SwitchbotModel",
+    "SwitchbotLightStrip",
     "SwitchbotLock",
-    "SwitchbotBlindTilt",
+    "SwitchbotModel",
+    "SwitchbotModel",
+    "SwitchbotPlugMini",
+    "SwitchbotPlugMini",
     "SwitchbotRelaySwitch",
+    "SwitchbotSupportedType",
+    "SwitchbotSupportedType",
+    "close_stale_connections",
+    "close_stale_connections_by_address",
+    "get_device",
+    "parse_advertisement_data",
 ]
