@@ -6,10 +6,10 @@ import asyncio
 import binascii
 import logging
 import time
+from collections.abc import Callable
 from dataclasses import replace
 from enum import Enum
 from typing import Any, TypeVar, cast
-from collections.abc import Callable
 from uuid import UUID
 
 import aiohttp
@@ -23,6 +23,7 @@ from bleak_retry_connector import (
     ble_device_has_changed,
     establish_connection,
 )
+from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
 
 from ..api_config import SWITCHBOT_APP_API_BASE_URL, SWITCHBOT_APP_CLIENT_ID
 from ..const import (
@@ -34,6 +35,7 @@ from ..const import (
     SwitchbotModel,
 )
 from ..discovery import GetSwitchbotDevices
+from ..helpers import create_background_task
 from ..models import SwitchBotAdvertisement
 
 _LOGGER = logging.getLogger(__name__)
@@ -45,6 +47,7 @@ REQ_HEADER = "570f"
 DEVICE_GET_BASIC_SETTINGS_KEY = "5702"
 DEVICE_SET_MODE_KEY = "5703"
 DEVICE_SET_EXTENDED_KEY = REQ_HEADER
+COMMAND_GET_CK_IV = f"{REQ_HEADER}2103"
 
 # Base key when encryption is set
 KEY_PASSWORD_PREFIX = "571"
@@ -81,7 +84,6 @@ class SwitchbotOperationError(Exception):
 
 def _sb_uuid(comms_type: str = "service") -> UUID | str:
     """Return Switchbot UUID."""
-
     _uuid = {"tx": "002", "rx": "003", "service": "d00"}
 
     if comms_type in _uuid:
@@ -167,8 +169,8 @@ class SwitchbotBaseDevice:
         session: aiohttp.ClientSession,
         subdomain: str,
         path: str,
-        data: dict = None,
-        headers: dict = None,
+        data: dict | None = None,
+        headers: dict | None = None,
     ) -> dict:
         url = f"https://{subdomain}.{SWITCHBOT_APP_API_BASE_URL}/{path}"
         async with session.post(
@@ -637,7 +639,8 @@ class SwitchbotBaseDevice:
         return result[index] in values
 
     def _update_parsed_data(self, new_data: dict[str, Any]) -> bool:
-        """Update data.
+        """
+        Update data.
 
         Returns true if data has changed and False if not.
         """
@@ -691,7 +694,8 @@ class SwitchbotBaseDevice:
 
 
 class SwitchbotDevice(SwitchbotBaseDevice):
-    """Base Representation of a Switchbot Device.
+    """
+    Base Representation of a Switchbot Device.
 
     This base class consumes the advertisement data during connection. If the device
     sends stale advertisement data while connected, use
@@ -827,9 +831,64 @@ class SwitchbotEncryptedDevice(SwitchbotDevice):
 
         return info is not None
 
+    async def _send_command(
+        self, key: str, retry: int | None = None, encrypt: bool = True
+    ) -> bytes | None:
+        if not encrypt:
+            return await super()._send_command(key[:2] + "000000" + key[2:], retry)
+
+        result = await self._ensure_encryption_initialized()
+        if not result:
+            _LOGGER.error("Failed to initialize encryption")
+            return None
+
+        encrypted = (
+            key[:2] + self._key_id + self._iv[0:2].hex() + self._encrypt(key[2:])
+        )
+        result = await super()._send_command(encrypted, retry)
+        return result[:1] + self._decrypt(result[4:])
+
+    async def _ensure_encryption_initialized(self) -> bool:
+        if self._iv is not None:
+            return True
+
+        result = await self._send_command(
+            COMMAND_GET_CK_IV + self._key_id, encrypt=False
+        )
+        ok = self._check_command_result(result, 0, {1})
+        if ok:
+            self._iv = result[4:]
+
+        return ok
+
+    async def _execute_disconnect(self) -> None:
+        await super()._execute_disconnect()
+        self._iv = None
+        self._cipher = None
+
+    def _get_cipher(self) -> Cipher:
+        if self._cipher is None:
+            self._cipher = Cipher(
+                algorithms.AES128(self._encryption_key), modes.CTR(self._iv)
+            )
+        return self._cipher
+
+    def _encrypt(self, data: str) -> str:
+        if len(data) == 0:
+            return ""
+        encryptor = self._get_cipher().encryptor()
+        return (encryptor.update(bytearray.fromhex(data)) + encryptor.finalize()).hex()
+
+    def _decrypt(self, data: bytearray) -> bytes:
+        if len(data) == 0:
+            return b""
+        decryptor = self._get_cipher().decryptor()
+        return decryptor.update(data) + decryptor.finalize()
+
 
 class SwitchbotDeviceOverrideStateDuringConnection(SwitchbotBaseDevice):
-    """Base Representation of a Switchbot Device.
+    """
+    Base Representation of a Switchbot Device.
 
     This base class ignores the advertisement data during connection and uses the
     data from the device instead.
@@ -847,7 +906,8 @@ class SwitchbotDeviceOverrideStateDuringConnection(SwitchbotBaseDevice):
 
 
 class SwitchbotSequenceDevice(SwitchbotDevice):
-    """A Switchbot sequence device.
+    """
+    A Switchbot sequence device.
 
     This class must not use SwitchbotDeviceOverrideStateDuringConnection because
     it needs to know when the sequence_number has changed.
@@ -866,4 +926,4 @@ class SwitchbotSequenceDevice(SwitchbotDevice):
             new_state,
         )
         if current_state != new_state:
-            asyncio.ensure_future(self.update())
+            create_background_task(self.update())
